@@ -4,7 +4,7 @@ use warnings;
 use strict;
 require DateTime::Format::Human::Duration::Locale;
 
-our $VERSION = '0.62';
+our $VERSION = '0.63';
 
 use Carp qw/croak/;
 
@@ -17,7 +17,11 @@ sub format_duration_between {
     my $dur = $dt - $dtb;
 
     if (!exists $args{'locale'}) {
-        $args{'locale'} = $dt->{'locale'}{'id'};
+	if (UNIVERSAL::can($dt->{'locale'}, 'code')) {
+	    $args{'locale'} = $dt->{'locale'}->code; # DateTime::Locale v1
+	} else {
+	    $args{'locale'} = $dt->{'locale'}->id;   # DateTime::Locale v0
+	}
     }
     
     return $span->format_duration($dur, %args);    
@@ -366,7 +370,7 @@ The idea is to determine the locale to use based on a DateTime object.
 
 XYZ::Locale should handle looking up (and caching if appropriate) the locale and loading the necessary locale module XYZ::Locale::fr
 
-The specific locale module holds the data and possibly logic neccesary to do what XYZ does in the vernacular of the given locale.
+The specific locale module holds the data and possibly logic necessary to do what XYZ does in the vernacular of the given locale.
 
 =head2 TODO 
 
